-----------------------
-- RaidKiller        --
-- By: Wire @ Byriel --
-----------------------

-- class
RaidKiller.Options.Tab.Donate = class(Wired.UI.Tab.Frame);

-- constants
RaidKiller.Options.Tab.Donate.Constants = {
  Name = "Donate Tab",
  Message = {
    Text = RK:T("UI.O.Donate")
  },
  Texture = {
    TeamWire = Wired.UI.Texture("RaidKiller", "Options/Tab/Resources/Team Wire.jpg"),
    Ratio = 360 / 640,
  }
};

-- defaults
RaidKiller.Options.Tab.Donate.Defaults = {
  Title = RK:T("UI.O.T.Donate"),
  Font = {
    Alpha = {
      Text = 0.75,
      Join = 0.75,
      Paypal = 0.75
    },
    Color = {
      Text = Wired.UI.Color.White,
      Join = Wired.UI.Color.White,
      Paypal = Wired.UI.Color.White
    },
    Size = {
      Text = 14,
      Join = 48,
      Paypal = 24
    },
    Text = {
      Join = RK:T("UI.O.M.L.Join"),
      Paypal = RK:T("UI.O.M.L.Paypal")
    }
  },
};

-- constructor
function RaidKiller.Options.Tab.Donate:Constructor(parent, application)
  Wired.UI.Tab.Frame.Constructor(self, RaidKiller.Options.Tab.Donate.Constants.Name, parent:GetFrame());
  
  -- parameters
  self:SetApplication(application);
  
  -- values
  self:SetTitle(RaidKiller.Options.Tab.Donate.Defaults.Title);
  self:SetPadding(0);
  self:SetColor(Wired.UI.Color.Clear);

  -- join label
  self.joinLabel = Wired.UI.Trion.Text("JoinLabel", self);
  self.joinLabel:SetFontColor(RaidKiller.Options.Tab.Donate.Defaults.Font.Color.Join);
  self.joinLabel:SetFontSize(RaidKiller.Options.Tab.Donate.Defaults.Font.Size.Join);
  self.joinLabel:SetAlpha(RaidKiller.Options.Tab.Donate.Defaults.Font.Alpha.Join);
  self.joinLabel:SetLayer(1);
  self.joinLabel:SetText(RaidKiller.Options.Tab.Donate.Defaults.Font.Text.Join);
  self.joinLabel:SetColor(Wired.UI.Color.Clear);
  self.joinLabel:SetVisible(true);
  
  -- paypal label
  self.paypalLabel = Wired.UI.Trion.Text("PaypalLabel", self);
  self.paypalLabel:SetFontColor(RaidKiller.Options.Tab.Donate.Defaults.Font.Color.Paypal);
  self.paypalLabel:SetFontSize(RaidKiller.Options.Tab.Donate.Defaults.Font.Size.Paypal);
  self.paypalLabel:SetAlpha(RaidKiller.Options.Tab.Donate.Defaults.Font.Alpha.Paypal);
  self.paypalLabel:SetLayer(1);
  self.paypalLabel:SetText(RaidKiller.Options.Tab.Donate.Defaults.Font.Text.Paypal);
  self.paypalLabel:SetColor(Wired.UI.Color.Clear);
  self.paypalLabel:SetVisible(true);
  
  -- team profile
  self.teamProfile = Wired.UI.Trion.Texture("TeamProfile", self);
  self.teamProfile:SetLayer(1);
  self.teamProfile:SetTexture(RaidKiller.Options.Tab.Donate.Constants.Texture.TeamWire);
  self.teamProfile:SetAlpha(0.75);
  self.teamProfile:SetVisible(true);
  
  -- team profile pane
  self.teamProfilePane = Wired.UI.Scroll.Frame("TeamProfilePane", self);
  self.teamProfilePane:SetColor(Wired.UI.Color.Clear);
  self.teamProfilePane:SetLayer(2);
  self.teamProfilePane:SetVisible(true);
  self.teamProfilePane:GetMask():SetColor(Wired.UI.Color.Clear);
  
  -- donate text
  local text = nil;
  for k, v in pairs(RaidKiller.Options.Tab.Donate.Constants.Message.Text) do
    if (text) then
      text = text .. "\n" .. v;
    else
      text = v;
    end
  end
  if (not text) then
    text = "";
  end
  
  -- donate label
  self.donateLabel = Wired.UI.Trion.Text("DonateLabel", self.teamProfilePane:GetMask());
  self.donateLabel:SetFontColor(RaidKiller.Options.Tab.Donate.Defaults.Font.Color.Text);
  self.donateLabel:SetFontSize(RaidKiller.Options.Tab.Donate.Defaults.Font.Size.Text);
  self.donateLabel:SetAlpha(RaidKiller.Options.Tab.Donate.Defaults.Font.Alpha.Text);
  self.donateLabel:SetLayer(3);
  self.donateLabel:SetWrapping(true);
  self.donateLabel:SetText(text);
  self.donateLabel:SetColor(Wired.UI.Color.Clear);
  self.donateLabel:SetVisible(true);
  
  -- add component
  self.teamProfilePane:SetComponent(self.donateLabel);
  self.teamProfilePane:SetComponentScale({
    horizontal = true,
    vertical = false
  });
  
  -- layout
  self:LayoutDonateTab();
end

-- application
function RaidKiller.Options.Tab.Donate:GetApplication()
  return self.application;
end

function RaidKiller.Options.Tab.Donate:SetApplication(value)
  self.application = value;
end

-- layout
function RaidKiller.Options.Tab.Donate:LayoutDonateTab()
  
  -- self
  self:SetWidth(self:GetParent():GetWidth());
  self:SetHeight(self:GetParent():GetHeight());
  
  -- team profile
  self.teamProfile:SetWidth(self:GetParent():GetWidth());
  self.teamProfile:SetHeight(RaidKiller.Options.Tab.Donate.Constants.Texture.Ratio * self.teamProfile:GetWidth());
  self.teamProfile:SetPoint({child = "CENTER", parent = "CENTER"}, {x = 0, y = 0});
  
  -- team profile pane
  self.teamProfilePane:SetWidth(self.teamProfile:GetWidth() * 0.75);
  self.teamProfilePane:SetHeight(self.teamProfile:GetHeight());
  self.teamProfilePane:SetPoint({child = "CENTER", parent = "CENTER"}, {x = 0, y = 0});
  
  -- donate label
  self.donateLabel:SetPoint({child = "CENTER", parent = "CENTER"}, {x = 0, y = 0});
  
  -- scroll
  self.teamProfilePane:Scroll();
  
  -- join label
  self.joinLabel:SetPoint({child = "BOTTOMCENTER", parent = "CENTER"}, {x = 0, y = -((self.teamProfile:GetHeight() / 2) + self:GetSpacing())});
  
  -- paypal label
  self.paypalLabel:SetPoint({child = "TOPCENTER", parent = "CENTER"}, {x = 0, y = ((self.teamProfile:GetHeight() / 2) + self:GetSpacing())});
end
