-----------------------
-- RaidKiller        --
-- By: Wire @ Byriel --
-----------------------

RaidKiller.Options.Window = class(Wired.UI.Window);

RaidKiller.Options.Window.Constants = {
  TeamWire = {
    Founders = {
      "Amarylis < Dark Horizon > @ Byriel",
    },
    Contributors = {
      "Value < Voodoo > @ Dayblind",
    },
    Translators = {
      "Liseane < LegendS > @ Brisesol",
      "Yakawar < Bloodlust > @ Brisesol",
      "Jabaun < Bloodlust > @ Brisesol",
      "Hunila < Relict > @ Rhazade",
    },
    Benefactors = {
      "Drudge @ Belmont",
      "< Tabula Rasa > @ Laethys",
      "Kalma < Ravenous > @ Wolfsbane",
      "Qanyena < Malus Imperium > @ Gnarlwood",
	  "<Malus Imperium> @ Gnarlwood"
      "Helga < Dawn of Terror > @ Seastone",
      "Mekamu < Play Nice > @ Estreal"
    }
  },
  Message = {
    Label = {
      Team = RK:T("UI.O.M.Team"),
      Join = RK:T("UI.O.M.Join")
    }
  }
};

RaidKiller.Options.Window.Defaults = {
  Spacing = 2,
  Padding = 2,
};

function RaidKiller.Options.Window:Constructor(name, parent, application)
  Wired.UI.Window.Constructor(self, name, parent);
  
  -- parameters
  self:SetApplication(application);
  
  -- self
  self:SetHeight(650);
  
  -- tab
  self:SetTab(Wired.UI.Tab.List(self:GetName() .. "_TabList", self:GetBase()));
  self:GetTab():SetPoint({child = "TOPCENTER", parent = "TOPCENTER"}, {x = 0, y = self:GetBorderSize().top + self:GetPadding()});
  self:GetTab():SetWidth(self:GetWidth() - self:GetBorderSize().left - self:GetBorderSize().right);
  self:GetTab():SetHeight(self:GetHeight() - self:GetBorderSize().top - self:GetBorderSize().bottom - self:GetSpacing() - 24);
  self:GetTab():SetLayer(2);
  self:GetTab():SetVisible(true);
  
  -- mechanics tab
  self:SetMechanicsTab(RaidKiller.Options.Tab.Mechanics(self:GetTab(), self:GetApplication()));
  self:GetTab():AddTab(self:GetMechanicsTab());
  
  -- size
  self:GetTab():SetWidth(self:GetMechanicsTab():GetWidth() + (self:GetTab():GetPadding() * 2));
  self:SetWidth(self:GetTab():GetWidth() + (self:GetPadding() * 2) + self:GetBorderSize().left + self:GetBorderSize().right);
  
  -- help tab
  self:SetHelpTab(RaidKiller.Options.Tab.Help(self:GetTab(), self:GetApplication()));
  self:GetTab():AddTab(self:GetHelpTab());
  
  -- about tab
  self:SetAboutTab(RaidKiller.Options.Tab.About(self:GetTab(), self:GetApplication()));
  self:GetTab():AddTab(self:GetAboutTab());
  
  -- donate tab
  self:SetDonateTab(RaidKiller.Options.Tab.Donate(self:GetTab(), self:GetApplication()));
  self:GetTab():AddTab(self:GetDonateTab());
  
  -- team label
  self:SetTeamLabel(Wired.UI.Trion.Text(self:GetName() .. "_TeamLabel", self:GetBase()));
  self:GetTeamLabel():SetPoint({child = "BOTTOMLEFT", parent = "BOTTOMLEFT"}, {x = self:GetBorderSize().left + self:GetPadding(), y = -(self:GetBorderSize().bottom + self:GetPadding())});
  self:GetTeamLabel():SetColor(Wired.UI.Color.Clear);
  self:GetTeamLabel():SetFontColor(Wired.UI.Color.White);
  self:GetTeamLabel():SetFontSize(18);
  self:GetTeamLabel():SetAlpha(0.75);
  self:GetTeamLabel():SetText(RaidKiller.Options.Window.Constants.Message.Label.Team);
  self:GetTeamLabel():SetVisible(true);
  
  -- join label
  self:SetJoinLabel(Wired.UI.Trion.Text(self:GetName() .. "_TeamLabel", self:GetBase()));
  self:GetJoinLabel():SetPoint({child = "BOTTOMRIGHT", parent = "BOTTOMRIGHT"}, {x = -(self:GetBorderSize().right + self:GetPadding()), y = -(self:GetBorderSize().bottom + self:GetPadding())});
  self:GetJoinLabel():SetColor(Wired.UI.Color.Clear);
  self:GetJoinLabel():SetFontColor(Wired.UI.Color.White);
  self:GetJoinLabel():SetFontSize(18);
  self:GetJoinLabel():SetAlpha(0.75);
  self:GetJoinLabel():SetText(RaidKiller.Options.Window.Constants.Message.Label.Join);
  self:GetJoinLabel():SetVisible(true);
  
  -- ticker
  self:SetTicker(Wired.UI.Animation.Ticker(self:GetName() .. "_Ticker", self:GetBase(), self:GetApplication()));
  self:GetTicker():SetPoint({child = "BOTTOMRIGHT", parent = "BOTTOMRIGHT"}, {x = -(self:GetBorderSize().right + self:GetPadding() + self:GetSpacing() + self:GetJoinLabel():GetWidth()), y = -(self:GetBorderSize().bottom + self:GetPadding())});
  self:GetTicker():SetColor(Wired.UI.Color.Clear);
  self:GetTicker():SetWidth(self:GetWidth() - self:GetTeamLabel():GetWidth() - self:GetJoinLabel():GetWidth() - (self:GetSpacing() * 2) - (self:GetPadding() * 2) - self:GetBorderSize().left - self:GetBorderSize().right);
  self:GetTicker():SetData(RaidKiller.Options.Window.Constants.TeamWire);
  self:GetTicker():SetLayer(1);
  self:GetTicker():SetVisible(true);
  
  -- team label clicked
  self:GetTeamLabel():GetBase().Wired.Event.Listener:Add(Wired.Event.Listener(
    "LeftClick",
    function()
    
      -- select
      self:GetTab():Select(self:GetDonateTab());
    end
  ));
  
  -- team label clicked
  self:GetJoinLabel():GetBase().Wired.Event.Listener:Add(Wired.Event.Listener(
    "LeftClick",
    function()
    
      -- select
      self:GetTab():Select(self:GetDonateTab());
    end
  ));
  
  -- team label clicked
  self:GetTicker():GetBase().Wired.Event.Listener:Add(Wired.Event.Listener(
    "LeftClick",
    function()
    
      -- select
      self:GetTab():Select(self:GetDonateTab());
    end
  ));
  
  -- visible changed
  self.Wired.Event.Listener:Add(Wired.Event.Listener(
    "VisibleChanged",
    function()
      
      -- animation
      local animation = self:GetTicker():GetTickerAnimation();
      
      -- select
      animation:SetActive(self:GetVisible());
      
      -- start
      if (not animation:GetStarted()) then
        animation:Start();
      end
    end,
    true
  ));
  
  -- select
  self:GetTab():Select(self:GetMechanicsTab());
end

-- application
function RaidKiller.Options.Window:GetApplication()
  return self.application;
end

function RaidKiller.Options.Window:SetApplication(value)
  self.application = value;
end

-- tab
function RaidKiller.Options.Window:GetTab()
  return self.tab;
end

function RaidKiller.Options.Window:SetTab(value)
  self.tab = value;
end

-- mechanics tab
function RaidKiller.Options.Window:GetMechanicsTab()
  return self.mechanicsTab;
end

function RaidKiller.Options.Window:SetMechanicsTab(value)
  self.mechanicsTab = value;
end

-- help tab
function RaidKiller.Options.Window:GetHelpTab()
  return self.helpTab;
end

function RaidKiller.Options.Window:SetHelpTab(value)
  self.helpTab = value;
end

-- about tab
function RaidKiller.Options.Window:GetAboutTab()
  return self.aboutTab;
end

function RaidKiller.Options.Window:SetAboutTab(value)
  self.aboutTab = value;
end

-- donate tab
function RaidKiller.Options.Window:GetDonateTab()
  return self.donateTab;
end

function RaidKiller.Options.Window:SetDonateTab(value)
  self.donateTab = value;
end

-- team label
function RaidKiller.Options.Window:GetTeamLabel()
  return self.teamLabel;
end

function RaidKiller.Options.Window:SetTeamLabel(value)
  self.teamLabel = value;
end

-- join label
function RaidKiller.Options.Window:GetJoinLabel()
  return self.joinLabel;
end

function RaidKiller.Options.Window:SetJoinLabel(value)
  self.joinLabel = value;
end

-- ticker
function RaidKiller.Options.Window:GetTicker()
  return self.ticker;
end

function RaidKiller.Options.Window:SetTicker(value)
  self.ticker = value;
end

-- spacing
function RaidKiller.Options.Window:GetSpacing()
  if (not self.spacing) then
    self.spacing = RaidKiller.Options.Window.Defaults.Spacing;
  end
  return self.spacing;
end

function RaidKiller.Options.Window:SetSpacing(value)
  self.spacing = value;
end

-- padding
function RaidKiller.Options.Window:GetPadding()
  if (not self.padding) then
    self.padding = RaidKiller.Options.Window.Defaults.Padding;
  end
  return self.padding;
end

function RaidKiller.Options.Window:SetPadding(value)
  self.padding = value;
end
